@@ -112,6 +112,8 @@ Glib::RefPtr<Gnome::Gda::DataModel> Base_DB::Query_execute(const Glib::ustring&
     result = gda_connection->execute_single_command(strQuery);
     if(!result)
     {
+      std::cerr << "Glom  Base_DB::Query_execute(): Error while executing SQL" << std::endl <<
+                   "  " <<  strQuery << std::endl;
       handle_error();
     }
   }
@@ -741,57 +743,8 @@ bool Base_DB::add_standard_tables() const
     //Name, address, etc:
     if(!get_table_exists_in_database(GLOM_STANDARD_TABLE_PREFS_TABLE_NAME))
     {
-      sharedptr<TableInfo> prefs_table_info(new TableInfo());
-      prefs_table_info->set_name(GLOM_STANDARD_TABLE_PREFS_TABLE_NAME);
-      prefs_table_info->set_title("System: Preferences"); //TODO: Provide standard translations.
-      prefs_table_info->m_hidden = true;
-
       Document_Glom::type_vecFields pref_fields;
-
-      sharedptr<Field> primary_key(new Field()); //It's not used, because there's only one record, but we must have one.
-      primary_key->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ID);
-      primary_key->set_glom_type(Field::TYPE_NUMERIC);
-      pref_fields.push_back(primary_key);
-
-      sharedptr<Field> field_name(new Field());
-      field_name->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_NAME);
-      field_name->set_glom_type(Field::TYPE_TEXT);
-      pref_fields.push_back(field_name);
-
-      sharedptr<Field> field_org_name(new Field());
-      field_org_name->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_NAME);
-      field_org_name->set_glom_type(Field::TYPE_TEXT);
-      pref_fields.push_back(field_org_name);
-
-      sharedptr<Field> field_org_address_street(new Field());
-      field_org_address_street->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_STREET);
-      field_org_address_street->set_glom_type(Field::TYPE_TEXT);
-      pref_fields.push_back(field_org_address_street);
-
-      sharedptr<Field> field_org_address_street2(new Field());
-      field_org_address_street2->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_STREET2);
-      field_org_address_street2->set_glom_type(Field::TYPE_TEXT);
-      pref_fields.push_back(field_org_address_street2);
-
-      sharedptr<Field> field_org_address_town(new Field());
-      field_org_address_town->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_TOWN);
-      field_org_address_town->set_glom_type(Field::TYPE_TEXT);
-      pref_fields.push_back(field_org_address_town);
-
-      sharedptr<Field> field_org_address_county(new Field());
-      field_org_address_county->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_COUNTY);
-      field_org_address_county->set_glom_type(Field::TYPE_TEXT);
-      pref_fields.push_back(field_org_address_county);
-
-      sharedptr<Field> field_org_address_country(new Field());
-      field_org_address_country->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_COUNTRY);
-      field_org_address_country->set_glom_type(Field::TYPE_TEXT);
-      pref_fields.push_back(field_org_address_country);
-
-      sharedptr<Field> field_org_address_postcode(new Field());
-      field_org_address_postcode->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_POSTCODE);
-      field_org_address_postcode->set_glom_type(Field::TYPE_TEXT);
-      pref_fields.push_back(field_org_address_postcode);
+      sharedptr<TableInfo> prefs_table_info = Document_Glom::create_table_system_preferences(pref_fields);
 
       const bool test = create_table(prefs_table_info, pref_fields);
 
@@ -1357,6 +1310,7 @@ void Base_DB::fill_full_field_details(const Glib::ustring& parent_table_name, sh
 {
   Glib::ustring table_name = parent_table_name;
 
+  //It might be a related field:
   if(layout_item->get_has_relationship_name())
   {
     sharedptr<const Relationship> rel = layout_item->get_relationship();;
@@ -1731,6 +1685,9 @@ sharedptr<Field> Base_DB::get_fields_for_table_one_field(const Glib::ustring& ta
   //Initialize output parameter:
   sharedptr<Field> result;
 
+  if(field_name.empty() || table_name.empty())
+    return result;
+
   type_vecFields fields = get_fields_for_table(table_name);
   type_vecFields::iterator iter = std::find_if(fields.begin(), fields.end(), predicate_FieldHasName<Field>(field_name));
   if(iter != fields.end()) //TODO: Handle error?
@@ -1849,6 +1806,14 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
 
             vecFields.push_back(layout_item);
           }
+          else
+          {
+            std::cerr << "Base_DB::get_table_fields_to_show_for_sequence_add_group(): related field not found: relationship=" << relationship_name << ", field=" << item->get_name() << std::endl;
+          }
+        }
+        else
+        {
+          std::cerr << "Base_DB::get_table_fields_to_show_for_sequence_add_group(): related field's relationship not found: " << relationship_name << std::endl;
         }
       }
       else //It's a regular field in the table:
