@@ -23,6 +23,8 @@
 #include "../data_structure/layout/report_parts/layoutitem_summary.h"
 #include "../data_structure/layout/report_parts/layoutitem_fieldsummary.h"
 #include "../data_structure/layout/layoutitem_button.h"
+#include "../standard_table_prefs_fields.h"
+#include <glibmm/i18n.h>
 //#include "config.h" //To get GLOM_DTD_INSTALL_DIR - dependent on configure prefix.
 #include <algorithm> //For std::find_if().
 #include <sstream> //For stringstream
@@ -42,6 +44,7 @@
 
 #define GLOM_NODE_DATA_LAYOUT_PORTAL "data_layout_portal"
 #define GLOM_NODE_DATA_LAYOUT_ITEM "data_layout_item" //A field.
+#define GLOM_ATTRIBUTE_LAYOUT_ITEM_CUSTOM_TITLE "title_custom"
 #define GLOM_NODE_DATA_LAYOUT_BUTTON "data_layout_button"
 #define GLOM_ATTRIBUTE_DATA_LAYOUT_ITEM_FIELD_USE_DEFAULT_FORMATTING "use_default_formatting"
 #define GLOM_NODE_DATA_LAYOUT_ITEM_GROUPBY "data_layout_item_groupby"
@@ -123,6 +126,9 @@
 #define GLOM_ATTRIBUTE_TRANSLATION_LOCALE "loc"
 #define GLOM_ATTRIBUTE_TRANSLATION_VALUE "val"
 
+//A built-in relationship that is available for every table:
+#define GLOM_RELATIONSHIP_NAME_SYSTEM_PROPERTIES "system_properties"
+
 Document_Glom::Document_Glom()
 : m_block_cache_update(false),
   m_block_modified_set(false),
@@ -225,10 +231,93 @@ void Document_Glom::set_relationship(const Glib::ustring& table_name, const shar
   }
 }
 
+sharedptr<Relationship> Document_Glom::create_relationship_system_preferences(const Glib::ustring& table_name)
+{
+  sharedptr<Relationship> relationship = sharedptr<Relationship>::create();
+  relationship->set_name(GLOM_RELATIONSHIP_NAME_SYSTEM_PROPERTIES);
+  relationship->set_title(_("System Preferences"));
+  relationship->set_from_table(table_name);
+  relationship->set_to_table(GLOM_STANDARD_TABLE_PREFS_TABLE_NAME);
+  relationship->set_allow_edit(false);
+
+  return relationship;
+}
+
+sharedptr<TableInfo> Document_Glom::create_table_system_preferences(type_vecFields& fields)
+{
+  sharedptr<TableInfo> prefs_table_info(new TableInfo());
+  prefs_table_info->set_name(GLOM_STANDARD_TABLE_PREFS_TABLE_NAME);
+  prefs_table_info->set_title(_("System Preferences"));
+  prefs_table_info->m_hidden = true;
+
+
+  fields.clear();
+
+  sharedptr<Field> primary_key(new Field()); //It's not used, because there's only one record, but we must have one.
+  primary_key->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ID);
+  primary_key->set_glom_type(Field::TYPE_NUMERIC);
+  fields.push_back(primary_key);
+
+  sharedptr<Field> field_name(new Field());
+  field_name->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_NAME);
+  field_name->set_title(_("System Name"));
+  field_name->set_glom_type(Field::TYPE_TEXT);
+  fields.push_back(field_name);
+
+  sharedptr<Field> field_org_name(new Field());
+  field_org_name->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_NAME);
+  field_org_name->set_title(_("Organisation Name"));
+  field_org_name->set_glom_type(Field::TYPE_TEXT);
+  fields.push_back(field_org_name);
+
+  sharedptr<Field> field_org_address_street(new Field());
+  field_org_address_street->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_STREET);
+  field_org_address_street->set_title(_("Street"));
+  field_org_address_street->set_glom_type(Field::TYPE_TEXT);
+  fields.push_back(field_org_address_street);
+
+  sharedptr<Field> field_org_address_street2(new Field());
+  field_org_address_street2->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_STREET2);
+  field_org_address_street2->set_title(_("Street (line 2)"));
+  field_org_address_street2->set_glom_type(Field::TYPE_TEXT);
+  fields.push_back(field_org_address_street2);
+
+  sharedptr<Field> field_org_address_town(new Field());
+  field_org_address_town->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_TOWN);
+  field_org_address_town->set_title(_("City"));
+  field_org_address_town->set_glom_type(Field::TYPE_TEXT);
+  fields.push_back(field_org_address_town);
+
+  sharedptr<Field> field_org_address_county(new Field());
+  field_org_address_county->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_COUNTY);
+  field_org_address_county->set_title(_("State"));
+  field_org_address_county->set_glom_type(Field::TYPE_TEXT);
+  fields.push_back(field_org_address_county);
+
+  sharedptr<Field> field_org_address_country(new Field());
+  field_org_address_country->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_COUNTRY);
+  field_org_address_country->set_title(_("Country"));
+  field_org_address_country->set_glom_type(Field::TYPE_TEXT);
+  fields.push_back(field_org_address_country);
+
+  sharedptr<Field> field_org_address_postcode(new Field());
+  field_org_address_postcode->set_name(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_POSTCODE);
+  field_org_address_postcode->set_title(_("Zip Code"));
+  field_org_address_postcode->set_glom_type(Field::TYPE_TEXT);
+  fields.push_back(field_org_address_postcode);
+
+  return prefs_table_info;
+}
+
 sharedptr<Relationship> Document_Glom::get_relationship(const Glib::ustring& table_name, const Glib::ustring& relationship_name) const
 {
   sharedptr<Relationship> result;
 
+  if(relationship_name == GLOM_RELATIONSHIP_NAME_SYSTEM_PROPERTIES)
+  {
+    return create_relationship_system_preferences(table_name);
+  }
+
   type_tables::const_iterator iterFind = m_tables.find(table_name);
   if(iterFind != m_tables.end())
   {
@@ -247,11 +336,22 @@ sharedptr<Relationship> Document_Glom::get_relationship(const Glib::ustring& tab
   return result;
 }
 
-Document_Glom::type_vecRelationships Document_Glom::get_relationships(const Glib::ustring& table_name) const
+Document_Glom::type_vecRelationships Document_Glom::get_relationships(const Glib::ustring& table_name, bool plus_system_prefs) const
 {
   type_tables::const_iterator iterFind = m_tables.find(table_name);
   if(iterFind != m_tables.end())
-    return iterFind->second.m_relationships;
+  {
+    type_vecRelationships result = iterFind->second.m_relationships;
+
+    //Add the system properties if necessary:
+    if(plus_system_prefs)
+    {
+        if(std::find_if(result.begin(), result.end(), predicate_FieldHasName<Relationship>(GLOM_STANDARD_TABLE_PREFS_TABLE_NAME)) == result.end())
+          result.push_back(create_relationship_system_preferences(table_name));
+    }
+
+    return result;
+  }
   else
     return type_vecRelationships(); 
 }
@@ -455,8 +555,18 @@ Document_Glom::type_vecFields Document_Glom::get_table_fields(const Glib::ustrin
     }
     else
     {
-      //g_warning("Document_Glom::get_table_fields: table not found in document: %s", table_name.c_str());
-      return type_vecFields();
+      //It's a standard table, not saved in the document:
+      if(table_name == GLOM_STANDARD_TABLE_PREFS_TABLE_NAME)
+      {
+        type_vecFields fields;
+        sharedptr<TableInfo> temp = create_table_system_preferences(fields);
+        return fields;
+      }
+      else
+      {
+        //g_warning("Document_Glom::get_table_fields: table not found in document: %s", table_name.c_str());
+        return type_vecFields();
+      }
     }
   }
   else
@@ -587,21 +697,21 @@ void Document_Glom::change_field_name(const Glib::ustring& table_name, const Gli
   }
 }
 
-void Document_Glom::change_table_name(const Glib::ustring& strTableNameOld, const Glib::ustring& strTableNameNew)
+void Document_Glom::change_table_name(const Glib::ustring& table_name_old, const Glib::ustring& table_name_new)
 {
-  type_tables::iterator iterFindTable = m_tables.find(strTableNameOld);
+  type_tables::iterator iterFindTable = m_tables.find(table_name_old);
   if(iterFindTable != m_tables.end())
   {
     //Change it:
     //We can't just change the key of the iterator (I think),
     //so we copy the whole thing and put it back in the map under a different key:
 
-    //iterFindTable->first = strTableNameNew;
+    //iterFindTable->first = table_name_new;
     DocumentTableInfo doctableinfo = iterFindTable->second;
     m_tables.erase(iterFindTable);
 
-    doctableinfo.m_info->set_name(strTableNameNew); 
-    m_tables[strTableNameNew] = doctableinfo; 
+    doctableinfo.m_info->set_name(table_name_new); 
+    m_tables[table_name_new] = doctableinfo; 
 
     //Find any relationships or layouts that use this table
     //Look at each table:
@@ -612,16 +722,16 @@ void Document_Glom::change_table_name(const Glib::ustring& strTableNameOld, cons
       {
         sharedptr<Relationship> relationship = *iterRels;
 
-        if(relationship->get_from_table() == strTableNameOld)
+        if(relationship->get_from_table() == table_name_old)
         {
           //Change it:
-           relationship->set_from_table(strTableNameNew);
+           relationship->set_from_table(table_name_new);
         }
 
-        if(relationship->get_to_table() == strTableNameOld)
+        if(relationship->get_to_table() == table_name_old)
         {
           //Change it:
-           relationship->set_to_table(strTableNameNew);
+           relationship->set_to_table(table_name_new);
         }
       }
     }
@@ -827,7 +937,7 @@ void Document_Glom::fill_layout_field_details(const Glib::ustring& parent_table_
     {
       if(layout_field->get_has_relationship_name()) //If it is a related field, instead of a field in parent_table_name
         layout_field->set_full_field_details( get_field(layout_field->get_relationship()->get_to_table(), layout_field->get_name()) );
-      else  
+      else
         layout_field->set_full_field_details( get_field(parent_table_name, layout_field->get_name()) );
     }
     else
@@ -1263,7 +1373,6 @@ void Document_Glom::load_after_layout_item_field_formatting(const xmlpp::Element
       get_node_attribute_value(element, GLOM_ATTRIBUTE_FORMAT_CHOICES_RELATED_SECOND) );
     //Full details are updated in filled-in ().
   }
-
 }
 
 void Document_Glom::load_after_layout_item_field(const xmlpp::Element* element, const Glib::ustring& table_name, const sharedptr<LayoutItem_Field>& item)
@@ -1284,6 +1393,15 @@ void Document_Glom::load_after_layout_item_field(const xmlpp::Element* element,
   }
 
   item->set_formatting_use_default( get_node_attribute_value_as_bool(element, GLOM_ATTRIBUTE_DATA_LAYOUT_ITEM_FIELD_USE_DEFAULT_FORMATTING) );
+
+
+  const xmlpp::Element* nodeCustomTitle = get_node_child_named(element, GLOM_ATTRIBUTE_LAYOUT_ITEM_CUSTOM_TITLE);
+  if(nodeCustomTitle)
+  {
+    sharedptr<CustomTitle> custom_title = sharedptr<CustomTitle>::create();
+    load_after_translations(nodeCustomTitle, *custom_title);
+    item->set_title_custom(custom_title);
+  }
 }
 
 void Document_Glom::load_after_layout_group(const xmlpp::Element* node, const Glib::ustring table_name, const sharedptr<LayoutGroup>& group)
@@ -1777,6 +1895,13 @@ void Document_Glom::save_before_layout_item_field(xmlpp::Element* nodeItem, cons
 
   set_node_attribute_value_as_bool(nodeItem, GLOM_ATTRIBUTE_DATA_LAYOUT_ITEM_FIELD_USE_DEFAULT_FORMATTING, field->get_formatting_use_default());
 
+  sharedptr<const CustomTitle> custom_title = field->get_title_custom();
+  if(custom_title)
+  {
+    xmlpp::Element* elementCustomTitle = nodeItem->add_child(GLOM_ATTRIBUTE_LAYOUT_ITEM_CUSTOM_TITLE);
+    save_before_translations(elementCustomTitle, *custom_title);
+  }
+
   set_node_attribute_value_as_decimal(nodeItem, GLOM_ATTRIBUTE_SEQUENCE, field->m_sequence);
 }
 
@@ -2406,6 +2531,18 @@ void Document_Glom::fill_translatable_layout_items(const sharedptr<LayoutGroup>&
       sharedptr<LayoutItem_Button> button = sharedptr<LayoutItem_Button>::cast_dynamic(item);
       if(button)
         the_list.push_back(button);
+      else
+      {
+        sharedptr<LayoutItem_Field> layout_field = sharedptr<LayoutItem_Field>::cast_dynamic(item);
+        if(layout_field)
+        {
+          sharedptr<CustomTitle> custom_title = layout_field->get_title_custom();
+          if(custom_title)
+          {
+            the_list.push_back(custom_title);
+          }
+        }
+      }
     }
   }
 }
