@@ -76,7 +76,7 @@ Box_Data_List::~Box_Data_List()
 
 void Box_Data_List::enable_buttons()
 {
-  const Privileges table_privs = get_current_privs(m_strTableName);
+  const Privileges table_privs = get_current_privs(m_table_name);
 
     //Enable/Disable record creation and deletion:
   bool allow_create = !m_read_only;
@@ -95,14 +95,13 @@ void Box_Data_List::enable_buttons()
 
 void Box_Data_List::refresh_data_from_database_blank()
 {
+  m_AddDel.set_where_clause(Glib::ustring());
   m_AddDel.refresh_from_database_blank();
-  m_AddDel.set_where_clause("");
+  m_where_clause = Glib::ustring();
 }
 
 bool Box_Data_List::fill_from_database()
 {
-  //std::cout << "Box_Data_List::fill_from_database(): where_clause=" << m_strWhereClause << std::endl;
-
   bool result = false;
 
   Bakery::BusyCursor(*get_app_window());
@@ -123,11 +122,11 @@ bool Box_Data_List::fill_from_database()
       //Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
 
     //Do not try to show the data if the user may not view it:
-    const Privileges table_privs = get_current_privs(m_strTableName);
+    const Privileges table_privs = get_current_privs(m_table_name);
 
     enable_buttons();
 
-    m_AddDel.set_where_clause(m_strWhereClause);
+    m_AddDel.set_where_clause(m_where_clause);
 
     result = m_AddDel.refresh_from_database();
 
@@ -188,7 +187,7 @@ void Box_Data_List::on_adddel_user_requested_add()
       bool test = get_field_column_index(m_FieldsShown[index_field_to_edit]->get_name(), treemodel_column);
       if(test)
       {
-        std::cout << "on_adddel_user_requested_add(): editing column=" << treemodel_column << std::endl;
+        //std::cout << "on_adddel_user_requested_add(): editing column=" << treemodel_column << std::endl;
         m_AddDel.select_item(iter, treemodel_column, true /* start_editing */);
       }
     }
@@ -245,7 +244,7 @@ void Box_Data_List::on_adddel_user_added(const Gtk::TreeModel::iterator& row, gu
   {
     //Auto-increment is awkward (we can't get the last-generated ID) with postgres, so we auto-generate it ourselves;
     const Glib::ustring& strPrimaryKeyName = field_primary_key->get_name();
-    primary_key_value = generate_next_auto_increment(m_strTableName, strPrimaryKeyName);  //TODO: return a Gnome::Gda::Value of an appropriate type.
+    primary_key_value = generate_next_auto_increment(m_table_name, strPrimaryKeyName);  //TODO: return a Gnome::Gda::Value of an appropriate type.
   }
   else
   {
@@ -315,7 +314,7 @@ void Box_Data_List::on_adddel_user_reordered_columns()
     Document_Glom::type_mapLayoutGroupSequence mapGroups;
     mapGroups[1] = group;
 
-    pDoc->set_data_layout_groups("list", m_strTableName, mapGroups);  
+    pDoc->set_data_layout_groups("list", m_table_name, mapGroups);  
   }
 }
 
@@ -330,13 +329,13 @@ void Box_Data_List::on_adddel_user_changed(const Gtk::TreeModel::iterator& row,
     {
       sharedptr<const LayoutItem_Field> layout_field = m_AddDel.get_column_field(col);
 
-      Glib::ustring table_name = m_strTableName;
+      Glib::ustring table_name = m_table_name;
       sharedptr<Field> primary_key_field;
       Gnome::Gda::Value primary_key_value;
 
       if(!layout_field->get_has_relationship_name())
       {
-        table_name = m_strTableName;
+        table_name = m_table_name;
         primary_key_field = m_AddDel.get_key_field();
         primary_key_value = parent_primary_key_value;
       }
@@ -348,7 +347,7 @@ void Box_Data_List::on_adddel_user_changed(const Gtk::TreeModel::iterator& row,
 
         Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
 
-        sharedptr<Relationship> relationship = document->get_relationship(m_strTableName, relationship_name);
+        sharedptr<Relationship> relationship = document->get_relationship(m_table_name, relationship_name);
         if(relationship)
         {
           table_name = relationship->get_to_table();
@@ -450,7 +449,7 @@ void Box_Data_List::refresh_related_fields(const Gtk::TreeModel::iterator& row,
 
   if(!fieldsToGet.empty())
   {
-    const Glib::ustring query = build_sql_select(m_strTableName, fieldsToGet, primary_key, primary_key_value);
+    const Glib::ustring query = build_sql_select(m_table_name, fieldsToGet, primary_key, primary_key_value);
 
     Glib::RefPtr<Gnome::Gda::DataModel> result = Query_execute(query);
     if(!result)
@@ -515,7 +514,7 @@ void Box_Data_List::do_lookups(const Gtk::TreeModel::iterator& row, const shared
 
         //Add it to the database (even if it is not shown in the view)
         set_field_value_in_database(row, layout_item, value_converted, primary_key, primary_key_value); //Also does dependent lookups/recalcs.
-        //Glib::ustring strQuery = "UPDATE \"" + m_strTableName + "\"";
+        //Glib::ustring strQuery = "UPDATE \"" + m_table_name + "\"";
         //strQuery += " SET " + field_lookup.get_name() + " = " + field_lookup.sql(value);
         //strQuery += " WHERE " + primary_key.get_name() + " = " + primary_key.sql(primary_key_value);
         //Query_execute(strQuery);  //TODO: Handle errors
@@ -622,6 +621,8 @@ Gnome::Gda::Value Box_Data_List::get_primary_key_value_selected()
 
 Gnome::Gda::Value Box_Data_List::get_primary_key_value_first()
 {
+  //std::cout << "Box_Data_List(): get_primary_key_value_first() records_count = " << m_AddDel.get_count() << std::endl;
+
   Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
   if(model)
   {
@@ -631,13 +632,18 @@ Gnome::Gda::Value Box_Data_List::get_primary_key_value_first()
       Gnome::Gda::Value value = get_primary_key_value(iter);
       if(GlomConversions::value_is_empty(value))
       {
+       //std::cout << "Box_Data_List(): get_primary_key_value_first() iter val is NULL" << std::endl;
         ++iter;
       }
       else
+      {
+         //std::cout << "Box_Data_List(): get_primary_key_value_first() returning: " << value.to_string() << std::endl;
         return value;
+      }
     }
   }
 
+ // std::cout << "Box_Data_List(): get_primary_key_value_first() return NULL" << std::endl;
   return Gnome::Gda::Value();
 }
 
@@ -667,9 +673,9 @@ void Box_Data_List::create_layout()
     m_AddDel.remove_all_columns();
     //m_AddDel.set_columns_count(m_Fields.size());
 
-    m_AddDel.set_table_name(m_strTableName);
+    m_AddDel.set_table_name(m_table_name);
 
-    sharedptr<Field> field_primary_key = get_field_primary_key_for_table(m_strTableName);
+    sharedptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
     if(!field_primary_key)
     {
       //g_warning("Box_Data_List::create_layout(): primary key not found.");
@@ -699,7 +705,7 @@ void Box_Data_List::create_layout()
         m_AddDel.add_column(field);
       }
 
-      m_AddDel.set_where_clause(m_strWhereClause);
+      m_AddDel.set_where_clause(m_where_clause);
 
       m_AddDel.set_columns_ready();
      }
@@ -755,7 +761,7 @@ bool Box_Data_List::get_field_primary_key_index(guint& field_column) const
 
 void Box_Data_List::print_layout()
 {
-  const Privileges table_privs = get_current_privs(m_strTableName);
+  const Privileges table_privs = get_current_privs(m_table_name);
 
   //Don't try to print tables that the user can't view.
   if(!table_privs.m_view)
@@ -775,7 +781,7 @@ void Box_Data_List::print_layout()
       report_temp->m_layout_group->add_item(*iter);
     }
 
-    report_build(m_strTableName, report_temp, m_strWhereClause);
+    report_build(m_table_name, report_temp, m_where_clause);
   }
 }
 
