@@ -62,7 +62,7 @@ protected:
     ModelColumns_Fields()
     { add(m_col_layout_item); add(m_col_sequence); }
 
-    Gtk::TreeModelColumn<LayoutItem_Field> m_col_layout_item;
+    Gtk::TreeModelColumn< sharedptr<LayoutItem_Field> > m_col_layout_item;
     Gtk::TreeModelColumn<guint> m_col_sequence;
   };
 
