@@ -36,7 +36,7 @@ Notebook_Data::Notebook_Data()
 
   //Allow List to ask Details to show a record.
   m_Box_List.signal_user_requested_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_list_user_requested_details));
-    
+
   //Allow Details to ask List to ask Details to show a different record:
   m_Box_Details.signal_nav_first().connect(sigc::mem_fun(m_Box_List, &Box_Data_List::on_details_nav_first));
   m_Box_Details.signal_nav_prev().connect(sigc::mem_fun(m_Box_List, &Box_Data_List::on_details_nav_previous));
@@ -62,37 +62,56 @@ Notebook_Data::~Notebook_Data()
   remove_view(&m_Box_Details);
 }
 
-bool Notebook_Data::init_db_details(const Glib::ustring& strTableName, const Glib::ustring& strWhereClause)
+bool Notebook_Data::init_db_details(const Glib::ustring& table_name, const Glib::ustring& where_clause)
 {
-  m_table_name = strTableName;
+  m_table_name = table_name;
 
   bool result = false;
-  //strWhereClause is only used as a result of a find.
+  //where_clause is only used as a result of a find.
 
   //Performance optimisation:
   //Keep the connection open during all these operations:
   {
     sharedptr<SharedConnection> sharedconnection = connect_to_server();
 
-    result = m_Box_List.init_db_details(m_table_name, strWhereClause);
+    const Glib::ustring old_where_clause = m_Box_List.get_where_clause();
+    //std::cout << "  old_where_clause=" << old_where_clause << std::endl;
+    //std::cout << "  where_clause=" << where_clause << std::endl;
+    const bool new_find_set = (where_clause != old_where_clause);
+    result = m_Box_List.init_db_details(m_table_name, where_clause);
     //m_Box_List.load_from_document();
-    
-    //Show the previously-shown record, if there is one,
+
+    //Show the previously-shown record, if there is one, if this is not a new found-set (via a new where_clause)
     //so that returning to this table will return the user to the same record:
     Document_Glom* document = get_document();
     if(document)
     {
-      Gnome::Gda::Value primary_key_for_details = document->get_layout_record_viewed(m_table_name, m_Box_Details.get_layout_name());
-      
+      Gnome::Gda::Value primary_key_for_details;
+
+      if(!new_find_set)
+      {
+        //std::cout << "debug: no new_found_set" << std::endl;
+        primary_key_for_details = document->get_layout_record_viewed(m_table_name, m_Box_Details.get_layout_name());
+      }
+      else
+      {
+         //std::cout << "debug: new_found_set" << std::endl;
+      }
+
       if(GlomConversions::value_is_empty(primary_key_for_details))
       {
         //Make sure that the details view is not empty, if there are any records to show:
         primary_key_for_details = m_Box_List.get_primary_key_value_selected();
+        //std::cout << "debug:  m_Box_List.get_primary_key_value_selected()=" << primary_key_for_details.to_string() << std::endl;
         if(GlomConversions::value_is_empty(primary_key_for_details))
+        {
+          //std::cout << "debug: calling list.get_primary_key_value_first()" << std::endl;
           primary_key_for_details = m_Box_List.get_primary_key_value_first();
+          //std::cout << "  debug:  result=" <<  primary_key_for_details.to_string() << std::endl;
+        }
       }
-      
-       m_Box_Details.init_db_details(m_table_name, primary_key_for_details);
+
+      m_Box_Details.init_db_details(m_table_name, primary_key_for_details);
     }
   }
 
@@ -114,16 +133,16 @@ bool Notebook_Data::init_db_details(const Glib::ustring& strTableName, const Gli
         else
           ++page;
       }
-      
+
       if(found)
       {
         set_current_page(page);
       }
     }
   }
-  
+
   if(!found)
-  {   
+  {
     //Select List as default:
     set_current_page(m_iPage_List);
   }
@@ -131,16 +150,21 @@ bool Notebook_Data::init_db_details(const Glib::ustring& strTableName, const Gli
   return result;
 }
 
+Glib::ustring Notebook_Data::get_where_clause() const
+{
+  return m_Box_List.get_where_clause();
+}
+
 void Notebook_Data::on_list_user_requested_details(const Gnome::Gda::Value& primary_key_value)
 {
-  m_Box_Details.refresh_data_from_database(primary_key_value);
+  m_Box_Details.refresh_data_from_database_with_primary_key(primary_key_value);
   set_current_page(m_iPage_Details);
 }
 
-void Notebook_Data::on_Details_user_requested_related_details(const Glib::ustring& strTableName, Gnome::Gda::Value primary_key_value)
+void Notebook_Data::on_Details_user_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value)
 {
-  signal_record_details_requested().emit(strTableName, primary_key_value);
-  
+  signal_record_details_requested().emit(table_name, primary_key_value);
+
   /*
   //Show a different table:
   init_db_details(m_table_name);
@@ -150,9 +174,17 @@ void Notebook_Data::on_Details_user_requested_related_details(const Glib::ustrin
   */
 }
 
+void Notebook_Data::set_current_view(dataview view)
+{
+  if(view == DATA_VIEW_List)
+    set_current_page(m_iPage_List);
+  else
+    set_current_page(m_iPage_Details);
+}
+
 void Notebook_Data::select_page_for_find_results()
 {
-  if(m_Box_List.get_records_count() > 1)
+  if(m_Box_List.get_showing_multiple_records())
   {
     set_current_page(m_iPage_List);
   }
@@ -185,7 +217,7 @@ void Notebook_Data::do_menu_file_print()
     Box_Data* pBox = dynamic_cast<Box_Data*>(pChild);
     if(pBox)
       pBox->print_layout();
-  } 
+  }
 }
 
 enum dataview
@@ -199,7 +231,7 @@ Notebook_Data::dataview Notebook_Data::get_current_view() const
   const int current_page = get_current_page();
 
   dataview result = DATA_VIEW_Details;
-  if(current_page == 1)
+  if(current_page == m_iPage_List)
     result = DATA_VIEW_List;
 
   return result;
@@ -232,6 +264,7 @@ void Notebook_Data::on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageN
     //And refresh the list view whenever it is shown, to 
     //a) show any new records that were added via the details view, or via a related portal elsewhere.
     //b) show changed field contents, changed elsewhere.
+    //TODO_Performance: This causes double refreshes (with database retrieval) when doing finds. We probably want to distinguish between user page-switches and programmatic page-switches.
     if(box == &m_Box_List)
     {
       Gnome::Gda::Value primary_key_selected = m_Box_List.get_primary_key_value_selected();
@@ -241,3 +274,8 @@ void Notebook_Data::on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageN
   }
 
 }
+
+void Notebook_Data::get_record_counts(gulong& total, gulong& found)
+{
+  m_Box_List.get_record_counts(total, found);
+}
