@@ -30,7 +30,7 @@ public:
   Dialog_Fields(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
   virtual ~Dialog_Fields();
 
-  virtual bool init_db_details(const Glib::ustring& strTableName);
+  virtual bool init_db_details(const Glib::ustring& table_name);
 
 protected:
 
