@@ -57,15 +57,28 @@ Box_Tables::~Box_Tables()
 {
 }
 
-void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const TableInfo& table_info)
+void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const sharedptr<const TableInfo>& table_info)
 {
   if(iter)
   {
-    m_AddDel.set_value_key(iter, table_info.m_name);
-    m_AddDel.set_value(iter, m_colTableName, table_info.m_name);
-    m_AddDel.set_value(iter, m_colHidden, table_info.m_hidden);
-    m_AddDel.set_value(iter, m_colTitle, table_info.m_title);
-    m_AddDel.set_value(iter, m_colDefault, table_info.m_default);
+    const bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
+
+    m_AddDel.set_value_key(iter, table_info->get_name());
+    m_AddDel.set_value(iter, m_colTableName, table_info->get_name());
+    m_AddDel.set_value(iter, m_colHidden, table_info->m_hidden);
+
+    if(developer_mode)
+    {
+      //std::cout << "Box_Tables::fill_table_row(): dev title=" << table_info->get_title() << std::endl;
+      m_AddDel.set_value(iter, m_colTitle, table_info->get_title());
+    }
+    else
+    {
+      //std::cout << "Box_Tables::fill_table_row(): op get_title_or_name=" << table_info->get_title_or_name() << std::endl;
+      m_AddDel.set_value(iter, m_colTitle, table_info->get_title_or_name());
+    }
+
+    m_AddDel.set_value(iter, m_colDefault, table_info->m_default);
   }
 }
 
@@ -76,7 +89,7 @@ bool Box_Tables::fill_from_database()
   bool result = Box_DB::fill_from_database();
 
   //Enable/Disable extra widgets:
-  bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
+  const bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
 
   //Developers see more columns, so make it bigger:
   if(developer_mode)
@@ -128,24 +141,27 @@ bool Box_Tables::fill_from_database()
     for(type_vecStrings::iterator iter = vecTables.begin(); iter != vecTables.end(); iter++)
     {
       const Glib::ustring strName = *iter;
-     
-      TableInfo table_info;
-      
+
+      sharedptr<TableInfo> table_info;
+
       //Check whether it should be hidden:
       Document_Glom::type_listTableInfo::iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
       if(iterFind != listTablesDocument.end())
       {
         table_info = *iterFind;
+
+        //std::cout << "fill_from_database(): name=" << (*iterFind)->get_name() << ", table_info->get_title()=" << (*iterFind)->get_title() << std::endl;
       }
       else
       {
         //This table is in the database, but not in the document.
         //Show it as hidden:
-        table_info.m_name = strName;
-        table_info.m_hidden = true;
+        table_info = sharedptr<TableInfo>(new TableInfo());
+        table_info->set_name(strName);
+        table_info->m_hidden = true;
       }
-      
-      bool hidden = iterFind->m_hidden;
+
+      const bool hidden = table_info->m_hidden;
 
       bool bAddIt = true;
       if(hidden && !developer_mode)  //Don't add hidden tables unless we are in developer mode:
@@ -155,7 +171,7 @@ bool Box_Tables::fill_from_database()
       {
         bAddIt = false;
       }
-      
+
       //Check whether it's a system table, though they should never be in this list:
       const Glib::ustring prefix = "glom_system_";
       const Glib::ustring table_prefix = strName.substr(0, prefix.size());
@@ -163,7 +179,7 @@ bool Box_Tables::fill_from_database()
       {
         bAddIt = false;
       }
-        
+
       if(bAddIt)
       {
         Gtk::TreeModel::iterator iter = m_AddDel.add_item(strName);
@@ -188,51 +204,53 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
   if(!table_name.empty())
   {
     //Primary key:
-    Field field_primary_key;
-    field_primary_key.set_name(table_name + "_id");
-    field_primary_key.set_primary_key();
-    field_primary_key.set_auto_increment();
+    sharedptr<Field> field_primary_key(new Field());
+    field_primary_key->set_name(table_name + "_id");
+    field_primary_key->set_title(table_name + " ID");
+    field_primary_key->set_primary_key();
+    field_primary_key->set_auto_increment();
 
-    Gnome::Gda::FieldAttributes field_info = field_primary_key.get_field_info();
+    Gnome::Gda::FieldAttributes field_info = field_primary_key->get_field_info();
     field_info.set_allow_null(false);
-    field_primary_key.set_field_info(field_info);
+    field_primary_key->set_field_info(field_info);
 
-    field_primary_key.set_glom_type(Field::TYPE_NUMERIC);
+    field_primary_key->set_glom_type(Field::TYPE_NUMERIC);
+    //std::cout << "field_primary_key->get_auto_increment():" << field_primary_key->get_auto_increment() << std::endl;
 
     type_vecFields fields;
     fields.push_back(field_primary_key);
 
     //Description:
-    Field field_description;
-    field_description.set_name("description");
-    field_description.set_title("Description");
-    field_description.set_glom_type(Field::TYPE_TEXT);
+    sharedptr<Field> field_description(new Field());
+    field_description->set_name("description");
+    field_description->set_title(_("Description")); //Use a translation, because the original locale will be marked as non-English if the current locale is non-English.
+    field_description->set_glom_type(Field::TYPE_TEXT);
     fields.push_back(field_description);
 
     //Comments:
-    Field field_comments;
-    field_comments.set_name("comments");
-    field_comments.set_title("Comments");
-    field_comments.set_glom_type(Field::TYPE_TEXT);
-    field_comments.m_default_formatting.set_text_format_multiline();
+    sharedptr<Field> field_comments(new Field());
+    field_comments->set_name("comments");
+    field_comments->set_title(_("Comments"));
+    field_comments->set_glom_type(Field::TYPE_TEXT);
+    field_comments->m_default_formatting.set_text_format_multiline();
     fields.push_back(field_comments);
 
-    TableInfo table_info;
-    table_info.m_name = table_name;
-    table_info.m_title = util_title_from_string( table_name ); //Start with a title that might be appropriate.
+    sharedptr<TableInfo> table_info(new TableInfo());
+    table_info->set_name(table_name);
+    table_info->set_title( util_title_from_string( table_name ) ); //Start with a title that might be appropriate.
 
-    bool test = create_table(table_info, fields);
+    const bool test = create_table(table_info, fields);
 
     //Create a table with 1 "ID" field:
    //MSYQL:
-    //Query_execute( "CREATE TABLE " + table_name + " (" + primary_key_name + " INT NOT NULL AUTO_INCREMENT PRIMARY KEY)" );
-    //Query_execute( "INSERT INTO " + table_name + " VALUES (0)" );
+    //Query_execute( "CREATE TABLE \"" + table_name + "\" (" + primary_key_name + " INT NOT NULL AUTO_INCREMENT PRIMARY KEY)" );
+    //Query_execute( "INSERT INTO \"" + table_name + "\" VALUES (0)" );
 
     //PostgresSQL:
     //Query_execute( "CREATE TABLE " + table_name + " (" + primary_key_name + " serial NOT NULL  PRIMARY KEY)" );
 
     //Query_execute( "CREATE TABLE \"" + table_name + "\" (" +
-    //  field_primary_key.get_name() + " numeric NOT NULL  PRIMARY KEY," + 
+    //  field_primary_key->get_name() + " numeric NOT NULL  PRIMARY KEY," + 
     //  extra_field_description + "varchar, " +
     //  extra_field_comments + "varchar" +
     //  ")" );
@@ -241,16 +259,16 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
     {
       //Show the new information for this whole row:
       fill_table_row(row, table_info);
-  
+
       //Save the field information directly into the database, because we cannot get all the correct information from the database.
       //Otherwise some information would be forgotten:
-      
-  
-  
+
+
+
       Document_Glom* document = get_document();
       if(document)
           document->set_table_fields(table_name, fields);
-  
+
       save_to_document();
       //fill_from_database(); //We should not modify the model structure in a cellrenderer signal handler.
     }
@@ -328,7 +346,7 @@ void Box_Tables::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
     else
     {
        //Go ahead:
-       
+ 
        save_to_document();
 
        //Emit the signal:
@@ -344,22 +362,28 @@ void Box_Tables::save_to_document()
     //Save the hidden tables. TODO_usermode: Only if we are in developer mode.
     Document_Glom::type_listTableInfo listTables;
 
+    Document_Glom* document = get_document();
+
     for(Gtk::TreeModel::iterator iter = m_AddDel.get_model()->children().begin(); iter != m_AddDel.get_model()->children().end(); ++iter)
     {
-      TableInfo table_info;
-      table_info.m_name = m_AddDel.get_value(iter, m_colTableName);
-
-      if(!table_info.m_name.empty())
+      const Glib::ustring table_name = m_AddDel.get_value(iter, m_colTableName); //The name has already been changed in the document.
+      sharedptr<TableInfo> table_info = document->get_table(table_name); //Start with the existing table_info, to preserve extra information, such as translations.
+      if(table_info)
       {
-        table_info.m_hidden  = m_AddDel.get_value_as_bool(iter, m_colHidden);
-        table_info.m_title  = m_AddDel.get_value(iter, m_colTitle);
-        table_info.m_default  = m_AddDel.get_value_as_bool(iter, m_colDefault);
+        table_info->set_name( m_AddDel.get_value(iter, m_colTableName) );
 
-        listTables.push_back(table_info);
+        if(!table_info->get_name().empty())
+        {
+          table_info->m_hidden  = m_AddDel.get_value_as_bool(iter, m_colHidden);
+          table_info->set_title( m_AddDel.get_value(iter, m_colTitle) ); //TODO_Translations: Store the TableInfo in the TreeView.
+          //std::cout << "save_to_document(): title=" << table_info->get_title() << std::endl;
+          table_info->m_default  = m_AddDel.get_value_as_bool(iter, m_colDefault);
+
+          listTables.push_back(table_info);
+        }
       }
     }
 
-    Document_Glom* document = get_document();
     if(document)
       document->set_tables( listTables); //TODO: Don't save all new tables - just the ones already in the document.
   }
@@ -382,7 +406,7 @@ void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint co
     else if( (column == m_colTitle) || (column == m_colDefault) )
     {
       save_to_document();
-    } 
+    }
     else if(column == m_colTableName)
     {
       Glib::ustring table_name = m_AddDel.get_value_key(row);
@@ -397,12 +421,12 @@ void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint co
         //Rename the table:
         if(iButtonClicked == Gtk::RESPONSE_OK)
         {
-          bool test = Query_execute( "ALTER TABLE " + table_name + " RENAME TO " + table_name_new);
+          bool test = Query_execute( "ALTER TABLE \"" + table_name + "\" RENAME TO \"" + table_name_new + "\"");
           if(test)
           {
             //Change the AddDel item's key:
             m_AddDel.set_value_key(row, table_name_new);
-            
+
             set_modified();
 
             //Tell the document that this table's name has changed:
